@@ -2,22 +2,14 @@ package URI::XS;
 use 5.012;
 use XS::Framework;
 
-our $VERSION = '1.1.7';
-
-use Export::XS::Auto
-    ALLOW_LEADING_AUTHORITY => 1,
-    PARAM_DELIM_SEMICOLON   => 2,
-;
+our $VERSION = '2.0.0';
 
 XS::Loader::bootstrap();
 
 require overload;
 overload->import(
     '""'     => \&to_string,
-    'eq'     => sub {
-        return ($_[0]->to_string eq $_[1]) unless ref $_[1];
-        return $_[0]->equals($_[1]);
-    },
+    'eq'     => \&equals,
     'bool'   => \&to_bool,
     #'='      => sub {$_[0]},
     fallback => 1,
